@@ -12,3 +12,7 @@ import (
 func Mount(node *core.IpfsNode, fsdir, nsdir, mfsdir string) error {
 	return errors.New("not compiled in")
 }
+
+func Unmount(node *core.IpfsNode) {
+	return
+}
