@@ -3,9 +3,9 @@ package cli
 import (
 	"testing"
 
+	"github.com/ipfs/go-test/random"
 	"github.com/ipfs/kubo/config"
 	"github.com/ipfs/kubo/test/cli/harness"
-	"github.com/ipfs/kubo/test/cli/testutils"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -21,7 +21,7 @@ func TestDHTOptimisticProvide(t *testing.T) {
 
 		nodes.StartDaemons().Connect()
 
-		hash := nodes[0].IPFSAddStr(testutils.RandomStr(100))
+		hash := nodes[0].IPFSAddStr(string(random.Bytes(100)))
 		nodes[0].IPFS("routing", "provide", hash)
 
 		res := nodes[1].IPFS("routing", "findprovs", "--num-providers=1", hash)
